@@ -1,4 +1,5 @@
-library(tsDyn)
+  library(tsDyn)
+suppressMessages(library(tidyverse))
 
 ###SETAR
 
@@ -36,9 +37,15 @@ sapply(set_all, function(x) head(regime(x, initVal=FALSE, time=FALSE),10))
 sapply(set_all, function(x) head(x$model,2))
 
 lapply(set_all[c(1,2,4)], toLatex)
+
+## coefs
+sapply(set_all, function(x) tail(coef(x, regime = "L"),4))
+sapply(set_all, function(x) tail(coef(x, regime = "H"),4))
+
+
 ###SelectSetar
-selectSETAR(lynx, m=2, d=1,  trace=TRUE, include = "const", common="none", model="TAR", nthresh=1,trim=0.15,criterion = "SSR",thSteps = 7,  plot=FALSE,max.iter=2)
-selectSETAR(lynx, m=2, d=1,  trace=TRUE, include = "const", common="none", model="TAR", nthresh=2,trim=0.15,criterion = "SSR",thSteps = 7,  plot=FALSE,max.iter=3)
+selectSETAR(lynx, m=2, d=1,  trace=TRUE, include = "const", common="none", model="TAR", nthresh=1,trim=0.15,criterion = "SSR", plot=FALSE,max.iter=2)
+selectSETAR(lynx, m=2, d=1,  trace=TRUE, include = "const", common="none", model="TAR", nthresh=2,trim=0.15,criterion = "SSR", plot=FALSE,max.iter=3)
 selectSETAR(lynx, m=2, d=1, th=MakeThSpec(ngrid="Half"), common="none",trim=0.15,criterion = "SSR", plot=FALSE)
 selectSETAR(lynx, m=2, d=1, th=MakeThSpec(ngrid=20), common="none",trim=0.15,criterion = "SSR", plot=FALSE)
 selectSETAR(lynx, m=2, d=1, th=MakeThSpec(exact=1388), common="none",trim=0.15,criterion = "SSR", plot=FALSE)
@@ -48,3 +55,21 @@ selectSETAR(lynx, m=2, d=1, th=MakeThSpec(int=c(957, 1824), ngrid=5), common="no
 selectSETAR(lynx, m=2, d=1, th=MakeThSpec(int=c(957, 1824), ngrid="Half"), common="none",criterion = "SSR", plot=FALSE)
 
 
+## setar.sim
+set_all_boot <- lapply(set_all, function(x) setar.boot(x, boot.scheme = "check", returnStarting = TRUE, round_digits=10))
+set_all_boot_check <-  sapply(set_all_boot, function(x) all.equal(x, as.numeric(lynx)))
+
+vals_df <- bind_cols(set_all_boot) %>%  
+  mutate(n_row = 1:n()) %>% 
+  gather(model, value, -n_row) %>% 
+  mutate(original = rep(as.numeric(lynx), length(set_all_boot)),
+         diff = abs(value-original) < 1e-010)
+
+if(FALSE) {
+  vals_df %>% 
+    filter(value!=original) %>% 
+    group_by(model) %>%
+    mutate(rmse = sqrt(mean(value-original)^2)) %>% 
+    filter(n_row ==min(n_row)) %>% 
+    select(-rmse)
+}
